<?php
/**
 * @file
 * Admin pages for the Zeitgeist module.
 *
 * @copyright  2005-2010 Ouest Systèmes Informatiques SARL (OSInet)
 *
 * @author Frédéric G. MARAND
 *
 * @license Licensed under the CeCILL version 2 and GPL version 2 or later
 *
 * License note: G2 is distributed by OSInet to its customers under the
 * CeCILL 2.0 license. OSInet support services only apply to the module
 * when distributed by OSInet, not by any third-party further down the
 * distribution chain.
 *
 * If you obtained G2 from drupal.org, that site received it under the
 * GPL v2 or later license and can therefore distribute it under the
 * GPL v2 or later, and so can you and just anyone down the chain as
 * long as the GPL v2 or later terms are abided by, the module
 * distributor in that case being the drupal.org organization or the
 * downstream distributor, not OSInet.
 */

/**
 * Implement a settings form.
 *
 * @return array An array containing form items to place on the module settings page.
 */
function _zeitgeist_admin_settings() {
  drupal_add_js(drupal_get_path('module', 'zeitgeist') .'/zeitgeist.js');

  $form[ZGVARHISTORY]     = array
    (
    '#type'               => 'textfield',
    '#title'              => t('Number of days of history'),
    '#description'        => t('Historical data are kept for that number of days. 0 means forever. Pruning is performed by cron on a daily basis'),
    '#default_value'      => variable_get(ZGVARHISTORY, ZGDEFHISTORY),
    '#size'               => 4, // this is good until 2037, should be enough for all 6.x needs.
    '#maxlength'          => 4,
    );

  $form['zeitgeist-display'] = array
    (
    '#type'               => 'fieldset',
    '#title'              => t('Display settings'),
    '#collapsible'        => TRUE,
    );

  $form['zeitgeist-display']['zeitgeist-top'] = array
    (
    '#type'               => 'fieldset',
    '#title'              => t('"Top searches" block'),
    '#collapsible'        => TRUE,
    '#collapsed'          => FALSE,
    );
  $form['zeitgeist-display']['zeitgeist-top'][ZGVARTOPCOUNT] = array
    (
    '#type'               => 'textfield',
    '#title'              => t('Top searches displayed'),
    '#description'        => t('This is the number of top searches displayed in the "Top Searches" block provided by the zeitgeist module. Default: %def.',
      array('%def' => ZGDEFTOPCOUNT)),
    '#default_value'      => variable_get(ZGVARTOPCOUNT, ZGDEFTOPCOUNT),
    '#maxlength'          => 2,
    '#size'               => 2,
    );
  $form['zeitgeist-display']['zeitgeist-top'][ZGVARTOPCACHE] = array
    (
    '#type'               => 'textfield',
    '#title'              => t('Cache expiration'),
    '#description'        => t('Block minimum caching duration in minutes (1 day = 1440 minutes). Note that blocks are cached as themed.'),
    '#default_value'      => variable_get(ZGVARTOPCACHE, 0),
    '#size'               => 5,
    '#maxlength'          => 5,
    );
  $form['zeitgeist-display']['zeitgeist-top'][ZGVARTOPDISPLAY] = array(
    '#type'               => 'radios',
    '#title'              => t('Display mode'),
    '#options'            => array('list' => t('HTML List'), 'implode' => t('Inline list with separators')),
    '#attributes'         => array('class' => 'container-inline'),
    '#default_value'      => variable_get(ZGVARTOPDISPLAY, ZGDEFDISPLAY),
  );
  $form['zeitgeist-display']['zeitgeist-top'][ZGVARTOPSEP] = array(
    '#type'               => 'textfield',
    '#title'              => t('Inline list separator'),
    '#description'        => t('If you chose "Inline list with separators" above, results will be separated by this string. You may use HTML.'),
    '#default_value'      => variable_get(ZGVARTOPSEP, ZGDEFVALSEP),
  );

  $form['zeitgeist-display']['zeitgeist-latest'] = array
    (
    '#type'               => 'fieldset',
    '#title'              => t('"Latest searches" block'),
    '#collapsible'        => TRUE,
    '#collapsed'          => FALSE,
    );
  $form['zeitgeist-display']['zeitgeist-latest'][ZGVARLATESTCOUNT] = array
    (
    '#type'               => 'textfield',
    '#title'              => t('Latest searches displayed'),
    '#description'        => t('This is the number of recent searches displayed in the "Latest Searches" block provided by the zeitgeist module. Default: %def.',
      array('%def' => ZGDEFLATESTCOUNT)),
    '#default_value'      => variable_get(ZGVARLATESTCOUNT, ZGDEFLATESTCOUNT),
    '#maxlength'          => 2,
    '#size'               => 2,
    );
  $form['zeitgeist-display']['zeitgeist-latest'][ZGVARTYPE]        = array
    (
    '#type'               => 'radios',
    '#title'              => t('When should the search type be displayed in the "Latest searches" block ?'),
    '#default_value'      => variable_get(ZGVARTYPE, ZGDEFTYPE),
    '#options'            => array
      (
      ZGDISPLAYTYPENEVER    => t('Never'),
      ZGDISPLAYTYPEADMIN    => t('Admin only'),
      ZGDISPLAYTYPEAUTH     => t('Authenticated users'),
      ZGDISPLAYTYPEALWAYS   => t('Always')
      ),
    '#description'        => t('<p>Recommended value is "Admin only"; "Always" is typically disturbing for visitors not already well-versed in Drupal.</p>'),
    );
  $form['zeitgeist-display']['zeitgeist-latest'][ZGVARLATESTCACHE] = array
    (
    '#type'               => 'textfield',
    '#title'              => t('Cache expiration'),
    '#description'        => t('Block minimum caching duration in minutes (1 day = 1440 minutes). Note that blocks are cached as themed.'),
    '#default_value'      => variable_get(ZGVARLATESTCACHE, 0),
    '#size'               => 5,
    '#maxlength'          => 5,
    );
  $form['zeitgeist-display']['zeitgeist-latest'][ZGVARLATESTDISPLAY] = array(
    '#type'               => 'radios',
    '#title'              => t('Display mode'),
    '#options'            => array('list' => t('HTML List'), 'implode' => t('Inline list with separators')),
    '#attributes'         => array('class' => 'container-inline'),
    '#default_value'      => variable_get(ZGVARLATESTDISPLAY, ZGDEFDISPLAY),
  );
  $form['zeitgeist-display']['zeitgeist-latest'][ZGVARLATESTSEP] = array(
    '#type'               => 'textfield',
    '#title'              => t('Inline list separator'),
    '#description'        => t('If you chose "Inline list with separators" above, results will be separated by this string. You may use HTML.'),
    '#default_value'      => variable_get(ZGVARLATESTSEP, ZGDEFVALSEP),
  );

  $form['zeitgeist-display']['zeitgeist-page'] = array
    (
    '#type'               => 'fieldset',
    '#title'              => t('Default zeitgeist page'),
    '#collapsible'        => TRUE,
    '#collapsed'          => TRUE,
    );
  $form['zeitgeist-display']['zeitgeist-page'][ZGVARPAGEHEIGHT]  = array
    (
    '#type'               => 'textfield',
    '#title'              => t('Height of the zeitgeist pager'),
    '#default_value'      => variable_get(ZGVARPAGEHEIGHT, ZGDEFPAGEHEIGHT),
    '#size'               => 3,
    '#maxlength'          => 3,
    );

  $form['zeigeist-filtering'] = array
    (
    '#type'               => 'fieldset',
    '#title'              => t('Search filtering'),
    '#collapsible'        => TRUE,
    '#collapsed'          => TRUE,
    );
  $form['zeigeist-filtering'][ZGVARVALIDATION]    = array
    (
    '#type'               => 'radios',
    '#title'              => t('How should search strings be validated to prevent spamming ZG blocks ?'),
    '#default_value'      => variable_get(ZGVARVALIDATION, ZGDEFVALIDATION),
    '#options'            => array
      (
      ZGVALIDATENO      => t('No validation performed: record and display every search'),
      ZGVALIDATERECORD  => t('Do not record searches containing HTML'),
      ZGVALIDATEDISPLAY => t('Do not display searches containing HTML, but store them'),
      ),
    '#description'        => t('<p>Recommended value is "Do not record HTML": spammers may abuse ZG by submitting links via scripts.</p>'),
    );
  $form['zeigeist-filtering'][ZGVARRECORDEMPTY] = array
    (
    '#type'               => 'checkbox',
    '#title'              => t('Should Zeitgeist record empty searches ?'),
    '#default_value'      => variable_get(ZGVARRECORDEMPTY, ZGDEFRECORDEMPTY),
    '#description'        => t('Zeitgeist normally records empty searches, but some of them can be spurious and not represent actual searches, but just clicks on search links by spiders, and some webmasters can wish to ignore them. Whatever this setting, they are never displayed in the "latest searches" block.'),
    );

  $form['advanced']       = array
    (
    '#type'               => 'fieldset',
    '#title'              => t('Advanced settings'),
    '#collapsible'        => TRUE,
    '#collapsed'          => TRUE
    );

  $form['advanced'][ZGVARNOFOLLOW]    = array
    (
    '#type'               => 'checkbox',
    '#title'              => t('Apply !attr to links on the "recent searches" and "top searches" blocks',
      array('!attr' => '<code>rel="nofollow"</code>')),
    '#default_value'      => variable_get(ZGVARNOFOLLOW, ZGDEFNOFOLLOW),
    '#return_value'       => 1,
    '#description'        => t('An attribute for the "a" (X)HTML alement, !attr is non-standard, but is recognized by several search engines, notably Google, MSN and Yahoo!',
      array('!attr' => '<code>rel="nofollow"</code>')),
    );
  $form['advanced'][ZGVERSION] = array
    (
    '#value'         => '<p>'
      . t('This site is running Zeitgeist version %version.', array('%version' => ZGVERSION))
      . '</p>'
    );

  /**
   * drupal_get_installed_schema_version is not available outside .install files
   * so we read it manually
   */
  $sq = 'SELECT schema_version '
      . 'FROM {system} '
      . "WHERE type='module' AND name='zeitgeist' ";
  // This form is only available to admins, so no need for db_rewrite_sql().
  $schema_version = db_result(db_query($sq));
  $form['advanced'][ZGSCHEMAVERSION] = array
    (
    '#value' => '<p>'
      . t('Zeitgeist schema is at version %version.', array('%version' => $schema_version))
      . '</p>'
    );

  $form['#submit'][] = '_zeitgeist_cache_clear';
  $form = system_settings_form($form);
  return $form;
}
